grab.spider.queue_backend.base — Grab 0.6.41 documentation

# `grab.spider.queue_backend.base`

## Module Contents

### Classes

`BaseTaskQueue` |

class grab.spider.queue_backend.base.BaseTaskQueue(**kwargs: Any)
  random_queue_name() → str
  abstract put(task: grab.spider.task.Task, priority: int, schedule_time: None | datetime = None) → None
  abstract get() → grab.spider.task.Task

    Return Task object or raise Queue.Empty exception.

    @returns: grab.spider.task.Task object @raises: Queue.Empty exception

  abstract size() → int
  abstract clear() → None

    Remove all tasks from the queue.

  abstract close() → None